==> kernel-2.3.5-alpha2-sources.jar: com/flybits/android/kernel/db/KernelDatabase.java <==
package com.flybits.android.kernel.db;

import android.arch.persistence.db.SupportSQLiteDatabase;
import android.arch.persistence.room.Database;
import android.arch.persistence.room.Room;
import android.arch.persistence.room.RoomDatabase;
import android.arch.persistence.room.TypeConverters;
import android.arch.persistence.room.migration.Migration;
import android.content.Context;
import android.support.annotation.NonNull;
import com.flybits.android.kernel.db.converters.JsonParserConverters;
import com.flybits.android.kernel.db.converters.ListStringConverters;
import com.flybits.android.kernel.db.converters.LocalizedValueConverters;
import com.flybits.android.kernel.db.dao.ContentDao;
import com.flybits.android.kernel.db.dao.GroupDao;
import com.flybits.android.kernel.models.Content;
import com.flybits.android.kernel.models.Group;

@Database(entities = {Content.class, Group.class}, version = 6)
@TypeConverters({LocalizedValueConverters.class, ListStringConverters.class, JsonParserConverters.class})
public abstract class KernelDatabase extends RoomDatabase {

    private static KernelDatabase INSTANCE;
    public abstract ContentDao contentDao();
    public abstract GroupDao groupDao();

    public static KernelDatabase getDatabase(Context context) {
        if (INSTANCE == null) {
            INSTANCE = Room.databaseBuilder(context, KernelDatabase.class, "flybits-kernel-db")
                    .addMigrations(MIGRATION_1_5, MIGRATION_3_5, MIGRATION_4_5, MIGRATION_5_6)
                    .fallbackToDestructiveMigration()
                    .build();
        }
        return INSTANCE;
    }

    static final Migration MIGRATION_5_6 = new Migration(5, 6)
    {
        @Override
        public void migrate(@NonNull SupportSQLiteDatabase database)
        {
            database.execSQL("ALTER TABLE content ADD COLUMN evaluatedAt INTEGER NOT NULL DEFAULT -1");
        }
    };

    static final Migration MIGRATION_4_5 = new Migration(4, 5)
    {
        @Override
        public void migrate(@NonNull SupportSQLiteDatabase database)
        {
            database.execSQL("ALTER TABLE content ADD COLUMN metadata TEXT");
            database.execSQL("ALTER TABLE content ADD COLUMN isFavourite INTEGER NOT NULL DEFAULT 0");
        }
    };

    static final Migration MIGRATION_3_5 = new Migration(3, 5) {
        @Override
        public void migrate(SupportSQLiteDatabase database) {
            database.execSQL("ALTER TABLE content ADD COLUMN labels TEXT");
            database.execSQL("ALTER TABLE content ADD COLUMN metadata TEXT");
            database.execSQL("ALTER TABLE content ADD COLUMN isFavourite INTEGER NOT NULL DEFAULT 0");
        }
    };
    static final Migration MIGRATION_1_5 = new Migration(1, 5) {
        @Override
        public void migrate(SupportSQLiteDatabase database) {
            database.execSQL("ALTER TABLE content ADD COLUMN labels TEXT");
            database.execSQL("ALTER TABLE content ADD COLUMN type TEXT");
            database.execSQL("ALTER TABLE content ADD COLUMN metadata TEXT");
            database.execSQL("ALTER TABLE content ADD COLUMN isFavourite INTEGER NOT NULL DEFAULT 0");
        }
    };

    public static void destroy() {
        INSTANCE = null;
    }

}

==> kernel-2.6.0-alpha2-sources.jar: com/flybits/android/kernel/db/KernelDatabase.java <==
package com.flybits.android.kernel.db;

import android.arch.persistence.db.SupportSQLiteDatabase;
import android.arch.persistence.room.Database;
import android.arch.persistence.room.Room;
import android.arch.persistence.room.RoomDatabase;
import android.arch.persistence.room.TypeConverters;
import android.arch.persistence.room.migration.Migration;
import android.content.Context;
import android.support.annotation.NonNull;
import com.flybits.android.kernel.db.converters.JsonParserConverters;
import com.flybits.android.kernel.db.converters.ListStringConverters;
import com.flybits.android.kernel.db.converters.LocalizedValueConverters;
import com.flybits.android.kernel.db.dao.ContentDao;
import com.flybits.android.kernel.db.dao.GroupDao;
import com.flybits.android.kernel.models.Content;
import com.flybits.android.kernel.models.Group;

@Database(entities = {Content.class, Group.class}, version = 7)
@TypeConverters({LocalizedValueConverters.class, ListStringConverters.class, JsonParserConverters.class})
public abstract class KernelDatabase extends RoomDatabase {

    private static KernelDatabase INSTANCE;
    public abstract ContentDao contentDao();
    public abstract GroupDao groupDao();

    public static KernelDatabase getDatabase(Context context) {
        if (INSTANCE == null) {
            INSTANCE = Room.databaseBuilder(context, KernelDatabase.class, "flybits-kernel-db")
                    .addMigrations(MIGRATION_1_5, MIGRATION_3_5, MIGRATION_4_5, MIGRATION_5_6, MIGRATION_6_7)
                    .fallbackToDestructiveMigration()
                    .build();
        }
        return INSTANCE;
    }

    static final Migration MIGRATION_6_7 = new Migration(6, 7)
    {
        @Override
        public void migrate(@NonNull SupportSQLiteDatabase database)
        {
            database.execSQL("ALTER TABLE content ADD COLUMN experienceId TEXT");
            database.execSQL("ALTER TABLE content ADD COLUMN pushRequestId TEXT");
        }
    };

    static final Migration MIGRATION_5_6 = new Migration(5, 6)
    {
        @Override
        public void migrate(@NonNull SupportSQLiteDatabase database)
        {
            database.execSQL("ALTER TABLE content ADD COLUMN evaluatedAt INTEGER NOT NULL DEFAULT -1");
        }
    };

    static final Migration MIGRATION_4_5 = new Migration(4, 5)
    {
        @Override
        public void migrate(@NonNull SupportSQLiteDatabase database)
        {
            database.execSQL("ALTER TABLE content ADD COLUMN metadata TEXT");
            database.execSQL("ALTER TABLE content ADD COLUMN isFavourite INTEGER");
        }
    };

    static final Migration MIGRATION_3_5 = new Migration(3, 5) {
        @Override
        public void migrate(SupportSQLiteDatabase database) {
            database.execSQL("ALTER TABLE content ADD COLUMN labels TEXT");
            database.execSQL("ALTER TABLE content ADD COLUMN metadata TEXT");
            database.execSQL("ALTER TABLE content ADD COLUMN isFavourite INTEGER");
        }
    };
    static final Migration MIGRATION_1_5 = new Migration(1, 5) {
        @Override
        public void migrate(SupportSQLiteDatabase database) {
            database.execSQL("ALTER TABLE content ADD COLUMN labels TEXT");
            database.execSQL("ALTER TABLE content ADD COLUMN type TEXT");
            database.execSQL("ALTER TABLE content ADD COLUMN metadata TEXT");
            database.execSQL("ALTER TABLE content ADD COLUMN isFavourite INTEGER");
        }
    };

    public static void destroy() {
        INSTANCE = null;
    }

}
